from setuptools import setup, find_packages

setup(name='thebrukhellomodule',
      version='5.0',
      description='Hello!',
      packages=find_packages(),
      author_email='thebrukprojects@gmail.com',
      zip_safe=False)
